@@ -34,4 +34,12 @@ test_that("Request code can be translated", {
   expect_identical({
     cms_translate(cli_code)
   }, cms_translate(python_code))
+})
+
+test_that("Jibberish as 'text' argument throws error", {
+  skip_on_cran()
+  skip_if_offline()
+  expect_error({
+    cms_translate("foobar")
+  }, "Code is not recognised")
 })
\ No newline at end of file
